Coverage for /Users/davegaeddert/Developer/dropseed/plain/plain-models/plain/models/sql/constants.py: 100%

1"""

2 Constants specific to the SQL storage portion of the ORM.

3"""

4

5# Size of each "chunk" for get_iterator calls.

6# Larger values are slightly faster at the expense of more storage space.

7 GET_ITERATOR_CHUNK_SIZE = 100

8

9# Namedtuples for sql.* internal use.

10

11# How many results to expect from a cursor.execute call

12 MULTI = "multi"

13 SINGLE = "single"

14 CURSOR = "cursor"

15 NO_RESULTS = "no results"

16

17 ORDER_DIR = {

18 "ASC": ("ASC", "DESC"),

19 "DESC": ("DESC", "ASC"),

20}

21

22# SQL join types.

23 INNER = "INNER JOIN"

24 LOUTER = "LEFT OUTER JOIN"